pub struct PatternCoverScorer;Expand description
Scores candidate pattern sets by greedy coverage over observed term shapes.
Implementations
Sourceimpl PatternCoverScorer
impl PatternCoverScorer
Sourcepub fn score_cover(
&self,
candidate_patterns: &[PatternSet],
egraph_ground_terms: &[TermShape],
) -> Vec<(usize, f64)>
pub fn score_cover( &self, candidate_patterns: &[PatternSet], egraph_ground_terms: &[TermShape], ) -> Vec<(usize, f64)>
Score pattern sets by greedy set cover over e-graph ground-term shapes.