pub struct PatternSet {
pub patterns: Vec<Pattern>,
pub matches: Vec<PatternMatch>,
pub covered_shapes: FxHashSet<TermShape>,
}Expand description
A set of patterns that must be matched together
Fields
patterns: Vec<Pattern>matches: Vec<PatternMatch>covered_shapes: FxHashSet<TermShape>Implementations
Sourceimpl PatternSet
impl PatternSet
Sourcepub fn from_patterns(patterns: Vec<Pattern>, manager: &TermManager) -> Self
pub fn from_patterns(patterns: Vec<Pattern>, manager: &TermManager) -> Self
Build a pattern set and precompute the term shapes it can match.