pub struct ModelCompleter { /* private fields */ }Expand description
Model completer that takes partial models and makes them complete
Implementations
Sourceimpl ModelCompleter
impl ModelCompleter
Sourcepub fn complete(
&mut self,
partial_model: &FxHashMap<TermId, TermId>,
quantifiers: &[QuantifiedFormula],
manager: &mut TermManager,
) -> Result<CompletedModel, CompletionError>
pub fn complete( &mut self, partial_model: &FxHashMap<TermId, TermId>, quantifiers: &[QuantifiedFormula], manager: &mut TermManager, ) -> Result<CompletedModel, CompletionError>
Complete a partial model using the Ge & de Moura (2009) approach.
Steps:
- Start from the partial SAT+theory model
- Extract function interpretations from Apply terms in the model
- Try to solve macro quantifiers (forall x. f(x) = body)
- Fix incomplete function interpretations (add else values)
- Handle uninterpreted sorts (create finite universes)
- Collect universes for all sorts from ground terms in model
- Set default values for every sort
- Ensure every function has a complete interpretation
Sourcepub fn stats(&self) -> &CompletionStats
pub fn stats(&self) -> &CompletionStats
Get completion statistics